Module ffi

Module ffi 

Utilities related to FFI bindings.

Structs

CStrNon-Windows and std
A dynamically-sized view of a C string.
CStringNon-Windows and std
A type representing an owned, C-compatible, nul-terminated string with no nul bytes in the middle.
NulErrorNon-Windows and std
An error indicating that an interior nul byte was found.

Enums

FromBytesWithNulErrorNon-Windows and std
An error indicating that a nul byte was not in the expected position.

Type Aliases

c_charstd
Equivalent to C’s char type.
c_intstd
Equivalent to C’s signed int (int) type.
c_longstd
Equivalent to C’s signed long (long) type.
c_longlongstd
Equivalent to C’s signed long long (long long) type.
c_shortstd
Equivalent to C’s signed short (short) type.
c_uintstd
Equivalent to C’s unsigned int type.
c_ulongstd
Equivalent to C’s unsigned long type.
c_ulonglongstd
Equivalent to C’s unsigned long long type.
c_ushortstd
Equivalent to C’s unsigned short type.
c_voidstd
Equivalent to C’s void type when used as a pointer.