fdatasync

Function fdatasync 

pub fn fdatasync<Fd: AsFd>(fd: Fd) -> Result<()>
Available on crate feature fs and neither apple nor DragonFly BSD nor target_os=espidf nor Haiku nor target_os=horizon nor Redox nor target_os=vita only.
fdatasync(fd)—Ensures that file data is written to the underlying storage device.

References