Struct Event

struct Event<'a> { ... }

An inotify event.

Implementations

impl<'a> Event<'a>

fn wd(self: &Self) -> i32

Returns the watch for which this event occurs.

fn events(self: &Self) -> ReadFlags

Returns a description of the events.

fn cookie(self: &Self) -> u32

Returns the unique cookie associating related events.

fn file_name(self: &Self) -> Option<&CStr>

Returns the file name of this event, if any.

impl<'a> Debug for Event<'a>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a> Freeze for Event<'a>

impl<'a> RefUnwindSafe for Event<'a>

impl<'a> Send for Event<'a>

impl<'a> Sync for Event<'a>

impl<'a> Unpin for Event<'a>

impl<'a> UnsafeUnpin for Event<'a>

impl<'a> UnwindSafe for Event<'a>

impl<T> Any for Event<'a>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Event<'a>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Event<'a>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Event<'a>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Event<'a>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Event<'a>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Event<'a>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>