Struct DirEntry

struct DirEntry { ... }

struct dirent

Implementations

impl DirEntry

fn file_name(self: &Self) -> &CStr

Returns the file name of this directory entry.

fn offset(self: &Self) -> i64

Returns the “offset” of this directory entry. This is not a true numerical offset but an opaque cookie that identifies a position in the given stream.

fn file_type(self: &Self) -> FileType

Returns the type of this directory entry.

fn ino(self: &Self) -> u64

Return the inode number of this directory entry.

impl Debug for DirEntry

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for DirEntry

impl RefUnwindSafe for DirEntry

impl Send for DirEntry

impl Sync for DirEntry

impl Unpin for DirEntry

impl UnsafeUnpin for DirEntry

impl UnwindSafe for DirEntry

impl<T> Any for DirEntry

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DirEntry

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DirEntry

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for DirEntry

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for DirEntry

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DirEntry

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DirEntry

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>