Gid

Struct Gid 

pub struct Gid(/* private fields */);
Available on crate feature fs only.
gid_t—A Unix group ID.

Implementations

Source

impl Gid

pub const ROOT: Self

Available on neither Windows nor WASI and (crate feature fs, or crate feature process, or crate feature thread, or linux_raw and non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature time or x86), or linux_kernel and crate feature net) only.

A Gid corresponding to the root group (gid 0).

pub fn from_raw(raw: RawGid) -> Self

Available on neither Windows nor WASI and (crate feature fs, or crate feature process, or crate feature thread, or linux_raw and non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature time or x86), or linux_kernel and crate feature net) only.

Converts a RawGid into a Gid.

raw must be the value of a valid Unix group ID, and not -1.

pub const fn from_raw_unchecked(raw: RawGid) -> Self

Available on neither Windows nor WASI and (crate feature fs, or crate feature process, or crate feature thread, or linux_raw and non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature time or x86), or linux_kernel and crate feature net) only.

Converts a RawGid into a Gid.

raw must be the value of a valid Unix group ID, and not -1.

pub const fn as_raw(self) -> RawGid

Available on neither Windows nor WASI and (crate feature fs, or crate feature process, or crate feature thread, or linux_raw and non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature time or x86), or linux_kernel and crate feature net) only.

Converts a Gid into a RawGid.

pub const fn is_root(self) -> bool

Available on neither Windows nor WASI and (crate feature fs, or crate feature process, or crate feature thread, or linux_raw and non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature time or x86), or linux_kernel and crate feature net) only.

Test whether this gid represents the root group (Gid::ROOT).