Struct RawDirEntry

struct RawDirEntry<'a> { ... }

A raw directory entry, similar to std::fs::DirEntry.

Unlike the std version, this may represent the . or .. entries.

Implementations

impl<'a> RawDirEntry<'a>

fn file_name(self: &Self) -> &CStr

Returns the file name of this directory entry.

fn file_type(self: &Self) -> FileType

Returns the type of this directory entry.

fn ino(self: &Self) -> u64

Returns the inode number of this directory entry.

fn next_entry_cookie(self: &Self) -> u64

Returns the seek cookie to the next directory entry.

impl<'a> Debug for RawDirEntry<'a>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'a> Freeze for RawDirEntry<'a>

impl<'a> RefUnwindSafe for RawDirEntry<'a>

impl<'a> Send for RawDirEntry<'a>

impl<'a> Sync for RawDirEntry<'a>

impl<'a> Unpin for RawDirEntry<'a>

impl<'a> UnsafeUnpin for RawDirEntry<'a>

impl<'a> UnwindSafe for RawDirEntry<'a>

impl<T> Any for RawDirEntry<'a>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for RawDirEntry<'a>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for RawDirEntry<'a>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for RawDirEntry<'a>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for RawDirEntry<'a>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for RawDirEntry<'a>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for RawDirEntry<'a>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>