pub struct IoringFeatureFlags(/* private fields */);io_uring only.Expand description
IORING_FEAT_* flags for use with io_uring_params.
Implementations
Sourceimpl IoringFeatureFlags
impl IoringFeatureFlags
Sourcepub const CUR_PERSONALITY: Self
pub const CUR_PERSONALITY: Self
IORING_FEAT_CUR_PERSONALITY
Sourcepub const NATIVE_WORKERS: Self
pub const NATIVE_WORKERS: Self
IORING_FEAT_NATIVE_WORKERS
Sourcepub const POLL_32BITS: Self
pub const POLL_32BITS: Self
IORING_FEAT_POLL_32BITS
Sourcepub const RW_CUR_POS: Self
pub const RW_CUR_POS: Self
IORING_FEAT_RW_CUR_POS
Sourcepub const SINGLE_MMAP: Self
pub const SINGLE_MMAP: Self
IORING_FEAT_SINGLE_MMAP
Sourcepub const SQPOLL_NONFIXED: Self
pub const SQPOLL_NONFIXED: Self
IORING_FEAT_SQPOLL_NONFIXED
Sourcepub const SUBMIT_STABLE: Self
pub const SUBMIT_STABLE: Self
IORING_FEAT_SUBMIT_STABLE
Sourcepub const LINKED_FILE: Self
pub const LINKED_FILE: Self
IORING_FEAT_LINKED_FILE
Sourcepub const REG_REG_RING: Self
pub const REG_REG_RING: Self
IORING_FEAT_REG_REG_RING
Sourcepub const RECVSEND_BUNDLE: Self
pub const RECVSEND_BUNDLE: Self
IORING_FEAT_RECVSEND_BUNDLE
Sourceimpl IoringFeatureFlags
impl IoringFeatureFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl IoringFeatureFlags
impl IoringFeatureFlags
Sourcepub const fn iter(&self) -> Iter<IoringFeatureFlags>
pub const fn iter(&self) -> Iter<IoringFeatureFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<IoringFeatureFlags>
pub const fn iter_names(&self) -> IterNames<IoringFeatureFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.