Enum Direction

enum Direction

The direction that an ioctl is going.

The direction is relative to userspace: Read means reading data from the kernel, and Write means the kernel writing data to userspace.

Variants

None

None of the above.

Read

Read data from the kernel.

Write

Write data to the kernel.

ReadWrite

Read and write data to the kernel.

Implementations

impl Clone for Direction

fn clone(self: &Self) -> Direction

impl Copy for Direction

impl Debug for Direction

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for Direction

impl Freeze for Direction

impl Hash for Direction

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for Direction

fn cmp(self: &Self, other: &Direction) -> Ordering

impl PartialEq for Direction

fn eq(self: &Self, other: &Direction) -> bool

impl PartialOrd for Direction

fn partial_cmp(self: &Self, other: &Direction) -> Option<Ordering>

impl RefUnwindSafe for Direction

impl Send for Direction

impl StructuralPartialEq for Direction

impl Sync for Direction

impl Unpin for Direction

impl UnsafeUnpin for Direction

impl UnwindSafe for Direction

impl<T> Any for Direction

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Direction

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Direction

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Direction

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Direction

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Direction

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Direction

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Direction

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Direction

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>