Function read_write

const fn read_write<T>(group: u8, number: u8) -> Opcode

Create a new reading and writing opcode from a group, a number and the type of data.

This corresponds to the C macro _IOWR(group, number, T).