Struct rustix::mount::MountAttrFlags
source · #[repr(transparent)]pub struct MountAttrFlags(_);mount only.Expand description
MOUNT_ATTR_* constants for use with fsmount.
Implementations
sourceimpl MountAttrFlags
impl MountAttrFlags
sourcepub const MOUNT_ATTR_RDONLY: Self = _
pub const MOUNT_ATTR_RDONLY: Self = _
MOUNT_ATTR_RDONLY
sourcepub const MOUNT_ATTR_NOSUID: Self = _
pub const MOUNT_ATTR_NOSUID: Self = _
MOUNT_ATTR_NOSUID
sourcepub const MOUNT_ATTR_NODEV: Self = _
pub const MOUNT_ATTR_NODEV: Self = _
MOUNT_ATTR_NODEV
sourcepub const MOUNT_ATTR_NOEXEC: Self = _
pub const MOUNT_ATTR_NOEXEC: Self = _
MOUNT_ATTR_NOEXEC
sourcepub const MOUNT_ATTR__ATIME: Self = _
pub const MOUNT_ATTR__ATIME: Self = _
MOUNT_ATTR__ATIME
sourcepub const MOUNT_ATTR_RELATIME: Self = _
pub const MOUNT_ATTR_RELATIME: Self = _
MOUNT_ATTR_RELATIME
sourcepub const MOUNT_ATTR_NOATIME: Self = _
pub const MOUNT_ATTR_NOATIME: Self = _
MOUNT_ATTR_NOATIME
sourcepub const MOUNT_ATTR_STRICTATIME: Self = _
pub const MOUNT_ATTR_STRICTATIME: Self = _
MOUNT_ATTR_STRICTATIME
sourcepub const MOUNT_ATTR_NODIRATIME: Self = _
pub const MOUNT_ATTR_NODIRATIME: Self = _
MOUNT_ATTR_NODIRATIME
sourcepub const MOUNT_ATTR_IDMAP: Self = _
pub const MOUNT_ATTR_IDMAP: Self = _
MOUNT_ATTR_NOUSER
sourcepub const MOUNT_ATTR_NOSYMFOLLOW: Self = _
pub const MOUNT_ATTR_NOSYMFOLLOW: Self = _
MOUNT_ATTR__ATIME_FLAGS
sourcepub const MOUNT_ATTR_SIZE_VER0: Self = _
pub const MOUNT_ATTR_SIZE_VER0: Self = _
MOUNT_ATTR__ATIME_FLAGS
sourceimpl MountAttrFlags
impl MountAttrFlags
sourcepub const fn from_bits(bits: c_uint) -> Option<Self>
pub const fn from_bits(bits: c_uint) -> Option<Self>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: c_uint) -> Self
pub const fn from_bits_truncate(bits: c_uint) -> Self
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const fn from_bits_retain(bits: c_uint) -> Self
pub const fn from_bits_retain(bits: c_uint) -> Self
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get the value for a flag from its stringified name.
Names are case-sensitive, so must correspond exactly to the identifier given to the flag.
sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Returns true if all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: Self)
pub fn insert(&mut self, other: Self)
Inserts the specified flags in-place.
This method is equivalent to union.
sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
Removes the specified flags in-place.
This method is equivalent to difference.
sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
Toggles the specified flags in-place.
This method is equivalent to symmetric_difference.
sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Inserts or removes the specified flags depending on the passed value.
sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection between the flags in self and
other.
Calculating self bitwise and (&) other, including
any bits that don’t correspond to a defined flag.
sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
Returns the union of between the flags in self and other.
Calculates self bitwise or (|) other, including
any bits that don’t correspond to a defined flag.
sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference between the flags in self and other.
Calculates self bitwise and (&!) the bitwise negation of other,
including any bits that don’t correspond to a defined flag.
This method is not equivalent to a & !b when there are bits set that
don’t correspond to a defined flag. The ! operator will unset any
bits that don’t correspond to a flag, so they’ll always be unset by a &! b,
but respected by a.difference(b).
sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference between the flags
in self and other.
Calculates self bitwise exclusive or (^) other,
including any bits that don’t correspond to a defined flag.
sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
Returns the complement of this set of flags.
Calculates the bitwise negation (!) of self,
unsetting any bits that don’t correspond to a defined flag.
sourceimpl MountAttrFlags
impl MountAttrFlags
sourcepub const fn iter(&self) -> Iter<MountAttrFlags>
pub const fn iter(&self) -> Iter<MountAttrFlags>
Iterate over enabled flag values.
sourcepub const fn iter_names(&self) -> IterNames<MountAttrFlags>
pub const fn iter_names(&self) -> IterNames<MountAttrFlags>
Iterate over enabled flag values with their stringified names.