pub struct MoveMountFlags(/* private fields */);mount only.Expand description
MOVE_MOUNT_* constants for use with move_mount.
Implementations
Sourceimpl MoveMountFlags
impl MoveMountFlags
Sourcepub const MOVE_MOUNT_F_SYMLINKS: Self
pub const MOVE_MOUNT_F_SYMLINKS: Self
MOVE_MOUNT_F_EMPTY_PATH
Sourcepub const MOVE_MOUNT_F_AUTOMOUNTS: Self
pub const MOVE_MOUNT_F_AUTOMOUNTS: Self
MOVE_MOUNT_F_AUTOMOUNTS
Sourcepub const MOVE_MOUNT_F_EMPTY_PATH: Self
pub const MOVE_MOUNT_F_EMPTY_PATH: Self
MOVE_MOUNT_F_EMPTY_PATH
Sourcepub const MOVE_MOUNT_T_SYMLINKS: Self
pub const MOVE_MOUNT_T_SYMLINKS: Self
MOVE_MOUNT_T_SYMLINKS
Sourcepub const MOVE_MOUNT_T_AUTOMOUNTS: Self
pub const MOVE_MOUNT_T_AUTOMOUNTS: Self
MOVE_MOUNT_T_AUTOMOUNTS
Sourcepub const MOVE_MOUNT_T_EMPTY_PATH: Self
pub const MOVE_MOUNT_T_EMPTY_PATH: Self
MOVE_MOUNT_T_EMPTY_PATH
Sourcepub const MOVE_MOUNT_SET_GROUP: Self
pub const MOVE_MOUNT_SET_GROUP: Self
MOVE_MOUNT__MASK
Sourcepub const MOVE_MOUNT_BENEATH: Self
pub const MOVE_MOUNT_BENEATH: Self
MOVE_MOUNT_BENEATH (since Linux 6.5)
Sourcepub const MOVE_MOUNT__MASK: Self
pub const MOVE_MOUNT__MASK: Self
MOVE_MOUNT__MASK
Sourceimpl MoveMountFlags
impl MoveMountFlags
Sourcepub const fn bits(&self) -> c_uint
pub const fn bits(&self) -> c_uint
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: c_uint) -> Option<Self>
pub const fn from_bits(bits: c_uint) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: c_uint) -> Self
pub const fn from_bits_truncate(bits: c_uint) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: c_uint) -> Self
pub const fn from_bits_retain(bits: c_uint) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl MoveMountFlags
impl MoveMountFlags
Sourcepub const fn iter(&self) -> Iter<MoveMountFlags>
pub const fn iter(&self) -> Iter<MoveMountFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<MoveMountFlags>
pub const fn iter_names(&self) -> IterNames<MoveMountFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.