Available on crate feature
net only.Expand description
Types for implementers of socket address types or code that is generic over address types.
The concrete address types and SocketAddrAny are in
the parent module.
Structs
- Socket
Addr Opaque - Opaque type equivalent to
sockaddrin C. - Socket
Addr Storage struct sockaddr_storage
Traits
- Socket
Addr Arg - A trait abstracting over the types that can be passed as a
sockaddr.
Type Aliases
- Socket
Addr Len - A type for the length of a socket address.