pub fn pipe() -> Result<(OwnedFd, OwnedFd)>Available on crate feature
pipe only.Expand description
pipe()—Creates a pipe.
This function creates a pipe and returns two file descriptors, for the reading and writing ends of the pipe, respectively.