pub fn pipe_with(flags: PipeFlags) -> Result<(OwnedFd, OwnedFd)>Available on crate feature
pipe only.Expand description
pipe2(flags)—Creates a pipe, with flags.
This function creates a pipe and returns two file descriptors, for the reading and writing ends of the pipe, respectively.