VirtualMemoryMapAddress

Enum VirtualMemoryMapAddress 

#[repr(u32)]
pub enum VirtualMemoryMapAddress { CodeStart = 1, CodeEnd = 2, DataStart = 3, DataEnd = 4, StackStart = 5, BrkStart = 6, BrkCurrent = 7, ArgStart = 8, ArgEnd = 9, EnvironmentStart = 10, EnvironmentEnd = 11, }
PR_SET_MM_* values for use with set_virtual_memory_map_address.

Variants



CodeStart = 1

Set the address above which the program text can run.



CodeEnd = 2

Set the address below which the program text can run.



DataStart = 3

Set the address above which initialized and uninitialized (bss) data are placed.



DataEnd = 4

Set the address below which initialized and uninitialized (bss) data are placed.



StackStart = 5

Set the start address of the stack.



BrkStart = 6

Set the address above which the program heap can be expanded with brk call.



BrkCurrent = 7

Set the current brk value.



ArgStart = 8

Set the address above which the program command line is placed.



ArgEnd = 9

Set the address below which the program command line is placed.



EnvironmentStart = 10

Set the address above which the program environment is placed.



EnvironmentEnd = 11

Set the address below which the program environment is placed.