getpriority_pgrp

Function getpriority_pgrp 

pub fn getpriority_pgrp(pgid: Option<Pid>) -> Result<i32>
Available on crate feature process and neither Fuchsia nor target_os=vita nor WASI and neither target_os=espidf nor target_os=horizon only.
getpriority(PRIO_PGRP, gid)—Get the scheduling priority of the given process group.

A pgid of None means the process group of the calling process.

References