pub fn set_executable_file(fd: BorrowedFd<'_>) -> Result<()>Available on crate feature
process only.Expand description
Supersede the /proc/pid/exe symbolic link with a new one pointing to a
new executable file.
pub fn set_executable_file(fd: BorrowedFd<'_>) -> Result<()>process only.Supersede the /proc/pid/exe symbolic link with a new one pointing to a
new executable file.