#[repr(C)]pub struct PrctlMmMap {}Expand description
This structure provides new memory descriptor map which mostly modifies
/proc/pid/stat[m] output for a task.
This mostly done in a sake of checkpoint/restore functionality.
Fields
start_code: u64Code section start address.
end_code: u64Code section end address.
start_data: u64Data section start address.
end_data: u64Data section end address.
start_brk: u64brk start address.
brk: u64brk current address.
start_stack: u64Stack start address.
arg_start: u64Program command line start address.
arg_end: u64Program command line end address.
env_start: u64Program environment start address.
env_end: u64Program environment end address.
auxv: *mut u64Auxiliary vector start address.
auxv_size: u32Auxiliary vector size.
exe_fd: RawFdFile descriptor of executable file that was used to create this process.