pub fn getrandom<Buf: Buffer<u8>>(
buf: Buf,
flags: GetRandomFlags,
) -> Result<Buf::Output>Expand description
getrandom(buf, flags)—Reads a sequence of random bytes.
This is a very low-level API which may be difficult to use correctly. Most
users should prefer to use getrandom or rand APIs instead.
This function is implemented using a system call, and not the vDSO mechanism introduced in Linux 6.11. See #1185 for details.