#[repr(u32)]pub enum OptionalActions {
Now = 0,
Drain = 1,
Flush = 2,
}Expand description
TCSA* values for use with tcsetattr.
Variants
Now = 0
TCSANOW—Make the change immediately.
Drain = 1
TCSADRAIN—Make the change after all output has been transmitted.
Flush = 2
TCSAFLUSH—Discard any pending input and then make the change
after all output has been transmitted.