Enum rustix::thread::CoreSchedulingScope
source · #[repr(u32)]
pub enum CoreSchedulingScope {
Thread,
ThreadGroup,
ProcessGroup,
}Available on crate feature
thread only.Expand description
PR_SCHED_CORE_SCOPE_*.
Variants
Thread
Operation will be performed for the thread.
ThreadGroup
Operation will be performed for all tasks in the task group of the process.
ProcessGroup
Operation will be performed for all processes in the process group.