#[repr(u8)]
pub enum SysCallUserDispatchFastSwitch {
Allow,
Block,
}Available on crate feature
thread only.Expand description
Value of the fast switch flag controlling system calls user dispatch mechanism without the need to issue a syscall.
Variants