Uid

Struct Uid 

pub struct Uid(/* private fields */);
Available on crate feature thread only.
uid_t—A Unix user ID.

Implementations

Source

impl Uid

pub const ROOT: Self

Available on neither Windows nor WASI and (crate feature fs, or crate feature process, or crate feature thread, or linux_raw and non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature time or x86), or linux_kernel and crate feature net) only.

A Uid corresponding to the root user (uid 0).

pub fn from_raw(raw: RawUid) -> Self

Available on neither Windows nor WASI and (crate feature fs, or crate feature process, or crate feature thread, or linux_raw and non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature time or x86), or linux_kernel and crate feature net) only.

Converts a RawUid into a Uid.

raw must be the value of a valid Unix user ID, and not -1.

pub const fn from_raw_unchecked(raw: RawUid) -> Self

Available on neither Windows nor WASI and (crate feature fs, or crate feature process, or crate feature thread, or linux_raw and non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature time or x86), or linux_kernel and crate feature net) only.

Converts a RawUid into a Uid.

raw must be the value of a valid Unix user ID, and not -1.

pub const fn as_raw(self) -> RawUid

Available on neither Windows nor WASI and (crate feature fs, or crate feature process, or crate feature thread, or linux_raw and non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature time or x86), or linux_kernel and crate feature net) only.

Converts a Uid into a RawUid.

pub const fn is_root(self) -> bool

Available on neither Windows nor WASI and (crate feature fs, or crate feature process, or crate feature thread, or linux_raw and non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature time or x86), or linux_kernel and crate feature net) only.

Test whether this uid represents the root user (Uid::ROOT).