Module event

Module event 

Available on crate feature event only.
Event operations.

Modules

epolllinux_kernel or illumos or Redox
Linux epoll support.

Structs

EventfdFlagslinux_kernel or FreeBSD or illumos or target_os=espidf
EFD_* flags for use with eventfd.
FdSetElement(bsd or linux_kernel or Windows or WASI) and linux_like
Storage element type for use with select.
FdSetIter(bsd or linux_kernel or Windows or WASI) and neither Windows nor WASI
An iterator over the fds in a set.
PollFd
struct pollfd—File descriptor and flags for use with poll.
PollFlags
POLL* flags for use with poll.
Timespec
struct timespec—A quantity of time in seconds plus nanoseconds.

Functions

eventfdlinux_kernel or FreeBSD or illumos or target_os=espidf
eventfd(initval, flags)—Creates a file descriptor for event notification.
fd_set_boundbsd or linux_kernel or Windows or WASI
Compute the minimum nfds value needed for the set pointed to by fds.
fd_set_insertbsd or linux_kernel or Windows or WASI
Set fd in the set pointed to by fds.
fd_set_num_elementsbsd or linux_kernel or Windows or WASI
Compute the number of FdSetElements needed to hold a set which can contain up to set_count file descriptors with values less than nfds.
fd_set_removebsd or linux_kernel or Windows or WASI
Clear fd in the set pointed to by fds.
pauseNeither Windows nor Redox nor WASI
pause()—Sleep until interrupted by a signal.
poll
poll(self.fds, timeout)—Wait for events on lists of file descriptors.
selectbsd or linux_kernel or Windows or WASI
select(nfds, readfds, writefds, exceptfds, timeout)—Wait for events on sets of file descriptors.

Type Aliases

Nsecs
A type for the tv_nsec field of Timespec.
Secs
A type for the tv_sec field of Timespec.