pub fn getn<Fd: AsFd, Buf: Buffer<Event>>(
port: Fd,
events: Buf,
min_events: u32,
timeout: Option<&Timespec>,
) -> Result<Buf::Output>Available on crate feature
event and solarish only.Expand description
port_getn(port, events, min_events, timeout)—Gets multiple events from
a port.
If events is empty, this does nothing and returns immediately.
To query the number of events without retrieving any, use getn_query.
If an unsupported timeout is passed, this function fails with
io::Errno::INVAL.