Timespec

Struct Timespec 

#[repr(C)]
pub struct Timespec { pub tv_sec: Secs, pub tv_nsec: Nsecs, }
Available on crate feature event only.
struct timespec—A quantity of time in seconds plus nanoseconds.

Fields

tv_sec: Secs

Seconds.

tv_nsec: Nsecs

Nanoseconds. Must be less than 1_000_000_000.

When passed to rustix::fs::utimensat, this field may instead be assigned the values UTIME_NOW or UTIME_OMIT.

Implementations

Source

impl Timespec

pub const fn checked_add(self, rhs: Self) -> Option<Self>

Available on crate feature fs, or crate feature event, or crate feature process, or crate feature runtime, or crate feature thread, or crate feature time, or crate feature event and (bsd or linux_kernel or Windows or WASI), or linux_raw and non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature process or crate feature runtime or crate feature time or x86) only.

Checked Timespec addition. Returns None if overflow occurred.

Panics

If 0 <= .tv_nsec < 1_000_000_000 doesn’t hold, this function may panic or return unexpected results.

Example
use rustix::event::Timespec;

assert_eq!(
    Timespec {
        tv_sec: 1,
        tv_nsec: 2
    }
    .checked_add(Timespec {
        tv_sec: 30,
        tv_nsec: 40
    }),
    Some(Timespec {
        tv_sec: 31,
        tv_nsec: 42
    })
);
assert_eq!(
    Timespec {
        tv_sec: 0,
        tv_nsec: 999_999_999
    }
    .checked_add(Timespec {
        tv_sec: 0,
        tv_nsec: 2
    }),
    Some(Timespec {
        tv_sec: 1,
        tv_nsec: 1
    })
);
assert_eq!(
    Timespec {
        tv_sec: i64::MAX,
        tv_nsec: 999_999_999
    }
    .checked_add(Timespec {
        tv_sec: 0,
        tv_nsec: 1
    }),
    None
);
pub const fn checked_sub(self, rhs: Self) -> Option<Self>

Available on crate feature fs, or crate feature event, or crate feature process, or crate feature runtime, or crate feature thread, or crate feature time, or crate feature event and (bsd or linux_kernel or Windows or WASI), or linux_raw and non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature process or crate feature runtime or crate feature time or x86) only.

Checked Timespec subtraction. Returns None if overflow occurred.

Panics

If 0 <= .tv_nsec < 1_000_000_000 doesn’t hold, this function may panic or return unexpected results.

Example
use rustix::event::Timespec;

assert_eq!(
    Timespec {
        tv_sec: 31,
        tv_nsec: 42
    }
    .checked_sub(Timespec {
        tv_sec: 30,
        tv_nsec: 40
    }),
    Some(Timespec {
        tv_sec: 1,
        tv_nsec: 2
    })
);
assert_eq!(
    Timespec {
        tv_sec: 1,
        tv_nsec: 1
    }
    .checked_sub(Timespec {
        tv_sec: 0,
        tv_nsec: 2
    }),
    Some(Timespec {
        tv_sec: 0,
        tv_nsec: 999_999_999
    })
);
assert_eq!(
    Timespec {
        tv_sec: i64::MIN,
        tv_nsec: 0
    }
    .checked_sub(Timespec {
        tv_sec: 0,
        tv_nsec: 1
    }),
    None
);