Utilities related to FFI bindings.
Structs
- CStr
Non-Windows and std - A dynamically-sized view of a C string.
- CString
Non-Windows and std - A type representing an owned, C-compatible, nul-terminated string with no nul bytes in the middle.
- NulError
Non-Windows and std - An error indicating that an interior nul byte was found.
Enums
- From
Bytes With NulError Non-Windows and std - An error indicating that a nul byte was not in the expected position.
Type Aliases
- c_char
std - Equivalent to C’s
chartype. - c_int
std - Equivalent to C’s
signed int(int) type. - c_long
std - Equivalent to C’s
signed long(long) type. - c_
longlong std - Equivalent to C’s
signed long long(long long) type. - c_short
std - Equivalent to C’s
signed short(short) type. - c_uint
std - Equivalent to C’s
unsigned inttype. - c_ulong
std - Equivalent to C’s
unsigned longtype. - c_
ulonglong std - Equivalent to C’s
unsigned long longtype. - c_
ushort std - Equivalent to C’s
unsigned shorttype. - c_void
std - Equivalent to C’s
voidtype when used as a pointer.