Struct Dir
struct Dir { ... }
DIR*
Implementations
impl Dir
fn new<Fd: Into<OwnedFd>>(fd: Fd) -> Result<Self>Take ownership of
fdand construct aDirthat reads entries from the given directory file descriptor.fn read_from<Fd: AsFd>(fd: Fd) -> Result<Self>Borrow
fdand construct aDirthat reads entries from the given directory file descriptor.fn rewind(self: &mut Self)rewinddir(self)fn seek(self: &mut Self, offset: i64) -> Result<()>seekdir(self, offset)This function is only available on 64-bit platforms because it's implemented using
libc::seekdirwhich only supports offsets that fit in ac_long.fn read(self: &mut Self) -> Option<Result<DirEntry>>readdir(self), whereNonemeans the end of the directory.fn stat(self: &Self) -> Result<Stat>fstat(self)fn statfs(self: &Self) -> Result<StatFs>fstatfs(self)fn statvfs(self: &Self) -> Result<StatVfs>fstatvfs(self)
impl Debug for Dir
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for Dir
impl Iterator for Dir
fn next(self: &mut Self) -> Option<<Self as >::Item>
impl RefUnwindSafe for Dir
impl Send for Dir
impl Sync for Dir
impl Unpin for Dir
impl UnsafeUnpin for Dir
impl UnwindSafe for Dir
impl<I> IntoIterator for Dir
fn into_iter(self: Self) -> I
impl<T> Any for Dir
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Dir
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Dir
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Dir
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Dir
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Dir
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Dir
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>