DirEntry

Struct DirEntry 

pub struct DirEntry { /* private fields */ }
Available on crate feature alloc and neither target_os=espidf nor Redox and crate feature fs only.
struct dirent

Implementations

Source

impl DirEntry

pub fn file_name(&self) -> &CStr

Available on crate feature fs, or non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature thread or crate feature time or x86) only.

Returns the file name of this directory entry.

pub fn offset(&self) -> i64

Available on crate feature fs, or non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature thread or crate feature time or x86) only.

Returns the “offset” of this directory entry. This is not a true numerical offset but an opaque cookie that identifies a position in the given stream.

pub fn file_type(&self) -> FileType

Available on crate feature fs, or non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature thread or crate feature time or x86) only.

Returns the type of this directory entry.

pub fn ino(&self) -> u64

Available on crate feature fs, or non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature thread or crate feature time or x86) only.

Return the inode number of this directory entry.