pub struct DirEntry { /* private fields */ }Available on crate feature
alloc and neither target_os=espidf nor Redox and crate feature fs only.Expand description
struct dirent
Implementations
Sourceimpl DirEntry
impl DirEntry
Sourcepub fn file_name(&self) -> &CStr
Available on crate feature fs, or non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature thread or crate feature time or x86) only.
pub fn file_name(&self) -> &CStr
fs, or non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature thread or crate feature time or x86) only.Returns the file name of this directory entry.
Sourcepub fn offset(&self) -> i64
Available on crate feature fs, or non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature thread or crate feature time or x86) only.
pub fn offset(&self) -> i64
fs, or non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature thread or crate feature time or x86) only.Returns the “offset” of this directory entry. This is not a true numerical offset but an opaque cookie that identifies a position in the given stream.
Sourcepub fn file_type(&self) -> FileType
Available on crate feature fs, or non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature thread or crate feature time or x86) only.
pub fn file_type(&self) -> FileType
fs, or non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature thread or crate feature time or x86) only.Returns the type of this directory entry.
Sourcepub fn ino(&self) -> u64
Available on crate feature fs, or non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature thread or crate feature time or x86) only.
pub fn ino(&self) -> u64
fs, or non-crate feature use-libc-auxv and non-crate feature use-explicitly-provided-auxv and (crate feature param or crate feature runtime or crate feature thread or crate feature time or x86) only.Return the inode number of this directory entry.