pub struct DecInt { /* private fields */ }Available on crate features
fs or net only.Expand description
Format an integer into a decimal Path component, without constructing a
temporary PathBuf or String.
This is used for opening paths such as /proc/self/fd/<fd> on Linux.
Example
use rustix::path::DecInt;
assert_eq!(
format!("hello {}", DecInt::new(9876).as_ref().display()),
"hello 9876"
);Implementations