#[repr(u32)]
pub enum Capability {
Show 41 variants ChangeOwnership, DACOverride, DACReadSearch, FileOwner, FileSetID, Kill, SetGroupID, SetUserID, SetPermittedCapabilities, LinuxImmutable, NetBindService, NetBroadcast, NetAdmin, NetRaw, IPCLock, IPCOwner, SystemModule, SystemRawIO, SystemChangeRoot, SystemProcessTrace, SystemProcessAccounting, SystemAdmin, SystemBoot, SystemNice, SystemResource, SystemTime, SystemTTYConfig, MakeNode, Lease, AuditWrite, AuditControl, SetFileCapabilities, MACOverride, MACAdmin, SystemLog, WakeAlarm, BlockSuspend, AuditRead, PerformanceMonitoring, BerkeleyPacketFilters, CheckpointRestore,
}
Available on crate feature thread only.
Linux per-thread capability.

Variants



ChangeOwnership

In a system with the _POSIX_CHOWN_RESTRICTED option defined, this overrides the restriction of changing file ownership and group ownership.



DACOverride

Override all DAC access, including ACL execute access if _POSIX_ACL is defined. Excluding DAC access covered by Capability::LinuxImmutable.



DACReadSearch

Overrides all DAC restrictions regarding read and search on files and directories, including ACL restrictions if _POSIX_ACL is defined. Excluding DAC access covered by Capability::LinuxImmutable.



FileOwner

Overrides all restrictions about allowed operations on files, where file owner ID must be equal to the user ID, except where Capability::FileSetID is applicable. It doesn’t override MAC and DAC restrictions.



FileSetID

Overrides the following restrictions that the effective user ID shall match the file owner ID when setting the S_ISUID and S_ISGID bits on that file; that the effective group ID (or one of the supplementary group IDs) shall match the file owner ID when setting the S_ISGID bit on that file; that the S_ISUID and S_ISGID bits are cleared on successful return from chown (not implemented).



Kill

Overrides the restriction that the real or effective user ID of a process sending a signal must match the real or effective user ID of the process receiving the signal.



SetGroupID

Allows setgid manipulation. Allows setgroups. Allows forged gids on socket credentials passing.



SetUserID

Allows set*uid manipulation (including fsuid). Allows forged pids on socket credentials passing.



SetPermittedCapabilities

Without VFS support for capabilities:

  • Transfer any capability in your permitted set to any pid.
  • remove any capability in your permitted set from any pid. With VFS support for capabilities (neither of above, but)
  • Add any capability from current’s capability bounding set to the current process’ inheritable set.
  • Allow taking bits out of capability bounding set.
  • Allow modification of the securebits for a process.


LinuxImmutable

Allow modification of S_IMMUTABLE and S_APPEND file attributes.



NetBindService

Allows binding to TCP/UDP sockets below 1024. Allows binding to ATM VCIs below 32.



NetBroadcast

Allow broadcasting, listen to multicast.



NetAdmin

Allow interface configuration. Allow administration of IP firewall, masquerading and accounting. Allow setting debug option on sockets. Allow modification of routing tables. Allow setting arbitrary process / process group ownership on sockets. Allow binding to any address for transparent proxying (also via Capability::NetRaw). Allow setting TOS (type of service). Allow setting promiscuous mode. Allow clearing driver statistics. Allow multicasting. Allow read/write of device-specific registers. Allow activation of ATM control sockets.



NetRaw

Allow use of RAW sockets. Allow use of PACKET sockets. Allow binding to any address for transparent proxying (also via Capability::NetAdmin).



IPCLock

Allow locking of shared memory segments. Allow mlock and mlockall (which doesn’t really have anything to do with IPC).



IPCOwner

Override IPC ownership checks.



SystemModule

Insert and remove kernel modules - modify kernel without limit.



SystemRawIO

Allow ioperm/iopl access. Allow sending USB messages to any device via /dev/bus/usb.



SystemChangeRoot

Allow use of chroot.



SystemProcessTrace

Allow ptrace of any process.



SystemProcessAccounting

Allow configuration of process accounting.



SystemAdmin

Allow configuration of the secure attention key. Allow administration of the random device. Allow examination and configuration of disk quotas. Allow setting the domainname. Allow setting the hostname. Allow mount and umount, setting up new smb connection. Allow some autofs root ioctls. Allow nfsservctl. Allow VM86_REQUEST_IRQ. Allow to read/write pci config on alpha. Allow irix_prctl on mips (setstacksize). Allow flushing all cache on m68k (sys_cacheflush). Allow removing semaphores. Used instead of Capability::ChangeOwnership to “chown” IPC message queues, semaphores and shared memory. Allow locking/unlocking of shared memory segment. Allow turning swap on/off. Allow forged pids on socket credentials passing. Allow setting readahead and flushing buffers on block devices. Allow setting geometry in floppy driver. Allow turning DMA on/off in xd driver. Allow administration of md devices (mostly the above, but some extra ioctls). Allow tuning the ide driver. Allow access to the nvram device. Allow administration of apm_bios, serial and bttv (TV) device. Allow manufacturer commands in isdn CAPI support driver. Allow reading non-standardized portions of pci configuration space. Allow DDI debug ioctl on sbpcd driver. Allow setting up serial ports. Allow sending raw qic-117 commands. Allow enabling/disabling tagged queuing on SCSI controllers and sending arbitrary SCSI commands. Allow setting encryption key on loopback filesystem. Allow setting zone reclaim policy. Allow everything under Capability::BerkeleyPacketFilters and Capability::PerformanceMonitoring for backward compatibility.



SystemBoot

Allow use of reboot.



SystemNice

Allow raising priority and setting priority on other (different UID) processes. Allow use of FIFO and round-robin (realtime) scheduling on own processes and setting the scheduling algorithm used by another process. Allow setting cpu affinity on other processes. Allow setting realtime ioprio class. Allow setting ioprio class on other processes.



SystemResource

Override resource limits. Set resource limits. Override quota limits. Override reserved space on ext2 filesystem. Modify data journaling mode on ext3 filesystem (uses journaling resources). NOTE: ext2 honors fsuid when checking for resource overrides, so you can override using fsuid too. Override size restrictions on IPC message queues. Allow more than 64hz interrupts from the real-time clock. Override max number of consoles on console allocation. Override max number of keymaps. Control memory reclaim behavior.



SystemTime

Allow manipulation of system clock. Allow irix_stime on mips. Allow setting the real-time clock.



SystemTTYConfig

Allow configuration of tty devices. Allow vhangup of tty.



MakeNode

Allow the privileged aspects of mknod.



Lease

Allow taking of leases on files.



AuditWrite

Allow writing the audit log via unicast netlink socket.



AuditControl

Allow configuration of audit via unicast netlink socket.



SetFileCapabilities

Set or remove capabilities on files. Map uid=0 into a child user namespace.



MACOverride

Override MAC access. The base kernel enforces no MAC policy. An LSM may enforce a MAC policy, and if it does and it chooses to implement capability based overrides of that policy, this is the capability it should use to do so.



MACAdmin

Allow MAC configuration or state changes. The base kernel requires no MAC configuration. An LSM may enforce a MAC policy, and if it does and it chooses to implement capability based checks on modifications to that policy or the data required to maintain it, this is the capability it should use to do so.



SystemLog

Allow configuring the kernel’s syslog (printk behaviour).



WakeAlarm

Allow triggering something that will wake the system.



BlockSuspend

Allow preventing system suspends.



AuditRead

Allow reading the audit log via multicast netlink socket.



PerformanceMonitoring

Allow system performance and observability privileged operations using perf_events, i915_perf and other kernel subsystems.



BerkeleyPacketFilters

This capability allows the following BPF operations:

  • Creating all types of BPF maps
  • Advanced verifier features
    • Indirect variable access
    • Bounded loops
    • BPF to BPF function calls
    • Scalar precision tracking
    • Larger complexity limits
    • Dead code elimination
    • And potentially other features
  • Loading BPF Type Format (BTF) data
  • Retrieve xlated and JITed code of BPF programs
  • Use bpf_spin_lock helper

Capability::PerformanceMonitoring relaxes the verifier checks further:

  • BPF progs can use of pointer-to-integer conversions
  • speculation attack hardening measures are bypassed
  • bpf_probe_read to read arbitrary kernel memory is allowed
  • bpf_trace_printk to print kernel memory is allowed

Capability::SystemAdmin is required to use bpf_probe_write_user.

Capability::SystemAdmin is required to iterate system wide loaded programs, maps, links, BTFs and convert their IDs to file descriptors.

Capability::PerformanceMonitoring and Capability::BerkeleyPacketFilters are required to load tracing programs. Capability::NetAdmin and Capability::BerkeleyPacketFilters are required to load networking programs.



CheckpointRestore

Allow checkpoint/restore related operations. Allow PID selection during clone3. Allow writing to ns_last_pid.